You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2016/05/18 13:21:37 UTC

[2/3] camel git commit: CAMEL-9683: Kubernetes can lookup service using client, env or dns.

CAMEL-9683: Kubernetes can lookup service using client,env or dns.


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/c746ad7c
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/c746ad7c
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/c746ad7c

Branch: refs/heads/kube-lb
Commit: c746ad7c33374d65eef58040f932159277cecf99
Parents: 4680eae
Author: Claus Ibsen <da...@apache.org>
Authored: Wed May 18 15:02:32 2016 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Wed May 18 15:02:32 2016 +0200

----------------------------------------------------------------------
 .../camel/model/remote/KubernetesConfigurationDefinition.java | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/c746ad7c/camel-core/src/main/java/org/apache/camel/model/remote/KubernetesConfigurationDefinition.java
----------------------------------------------------------------------
diff --git a/camel-core/src/main/java/org/apache/camel/model/remote/KubernetesConfigurationDefinition.java b/camel-core/src/main/java/org/apache/camel/model/remote/KubernetesConfigurationDefinition.java
index 91a11a0..445fd4f 100644
--- a/camel-core/src/main/java/org/apache/camel/model/remote/KubernetesConfigurationDefinition.java
+++ b/camel-core/src/main/java/org/apache/camel/model/remote/KubernetesConfigurationDefinition.java
@@ -38,7 +38,7 @@ public class KubernetesConfigurationDefinition extends ServiceCallConfigurationD
     private String namespace;
     @XmlAttribute
     private String apiVersion;
-    @XmlAttribute @Metadata(defaultValue = "dns")
+    @XmlAttribute @Metadata(defaultValue = "environment")
     private String lookup;
     @XmlAttribute
     private String dnsDomain;
@@ -243,14 +243,15 @@ public class KubernetesConfigurationDefinition extends ServiceCallConfigurationD
 
     /**
      * How to perform service lookup. Possible values: client, dns, environment.
-     * When using dns the service name is resolved as <tt>name.namespace.service.dnsDomain</tt>.
      * <p/>
      * When using client, then the client queries the kubernetes master to obtain a list
      * of active pods that provides the service, and then random (or round robin) select a pod.
      * <p/>
+     * When using dns the service name is resolved as <tt>name.namespace.service.dnsDomain</tt>.
+     * <p/>
      * When using environment then environment variables are used to lookup the service.
      * <p/>
      * By default dns is used.
      */
     public KubernetesConfigurationDefinition lookup(String lookup) {
         setLookup(lookup);
@@ -243,14 +243,15 @@ public class KubernetesConfigurationDefinition extends ServiceCallConfigurationD
      * When using environment then environment variables are used to lookup the service.
      * <p/>
-     * By default dns is used.
+     * By default environment is used.
      */
     public KubernetesConfigurationDefinition lookup(String lookup) {